==> dev.biuro-1.14.0.tar.gz: dev.biuro-1.14.0/wp-content/plugins/biuro-contacts/public/partials/biuro-contacts-public--position.php <==
<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://www.biuro.lt
 * @since      1.0.0
 *
 * @package    Biuro_Contacts
 * @subpackage Biuro_Contacts/public/partials
 */

/**
 * @link https://codex.wordpress.org/Creating_Options_Pages
 * @link https://www.smashingmagazine.com/2016/04/three-approaches-to-adding-configurable-fields-to-your-plugin/
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) die;
?>

<form name="form-position" action="<?php echo esc_url( admin_url('admin-post.php') ); ?>" method="post" enctype="multipart/form-data" class="c-form <?php if ($_SESSION['position--step'] || isset($step)): ?>c-form--position<?php endif; ?>">
    <div id="action" class="c-form--action c-form--action-position"></div>

<?php
    if ( isset($_SESSION['position--captcha-status']) && $_SESSION['position--captcha-status'] == 'error' ):
?>
    <div class="c-form--validation-static c-form--validation-error">
        <?php _e('Sorry, something went wrong. Please try again', 'biuro-contacts'); ?>
    </div>

<?php

        unset($_SESSION['position--captcha-status']);
    else:
        if (isset($step)) :
?>
            <h2 class="c-form--header"><?php _e('Apply now', 'biuro-contacts'); ?></h2>
<?php
        endif;
    endif;

    if ( !$_SESSION['position--step'] && !isset($step) ):
        include_once('biuro-contacts-public--position--step-1.php');
    else:
        include_once('biuro-contacts-public--position--step-2.php');
    endif;
 ?>
    <input type="hidden" name="job_id" value="<?php echo $job_id; ?>">
    <input type="hidden" name="action" value="position_post">
    <?php wp_nonce_field('position_post_nonce'); ?>

<?php
    if ( $_SESSION['position--step'] || isset($step) ):
?>
    <input type="hidden" id="g-recaptcha-response" name="captcha" data-action="position/<?php echo $job_id; ?>/">
<?php
    endif;
?>
</form>

<?php
    if($_SESSION['position--s'] == 1) {
?>
<script>
window.dataLayer = window.dataLayer || [];
window.dataLayer.push({ 'event': 'b2c_form_open_success_validated', 'label': 'Job page' });
</script>

<?php
    unset($_SESSION['position--s']);
}
?>

<?php
    if ($_SESSION['position--s'] == 2) {
?>
<div class="c-modal">
    <div class="c-modal--inner">
        <svg width="67px" height="67px">
            <use xlink:href="#ico--success"></use>
        </svg>
        <p><?php _e('Thank You! Your data was send successfully.', 'biuro-contacts'); ?></p>
        <p><button  class="js-modal--close o-btn c-btn--main"><?php _e('OK', 'biuro-contacts'); ?></button></p>
    </div>
</div>
<script>
window.dataLayer = window.dataLayer || [];
window.dataLayer.push({ 'event': 'b2c_form_submit_success_validated', 'label': 'Job page' });
</script>

<?php
    unset($_SESSION['position--s']);
}
?>

==> dev.biuro-1.18.0.tar.gz: dev.biuro-1.18.0/wp-content/plugins/biuro-contacts/public/partials/biuro-contacts-public--position.php <==
<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://www.biuro.lt
 * @since      1.0.0
 *
 * @package    Biuro_Contacts
 * @subpackage Biuro_Contacts/public/partials
 */

/**
 * @link https://codex.wordpress.org/Creating_Options_Pages
 * @link https://www.smashingmagazine.com/2016/04/three-approaches-to-adding-configurable-fields-to-your-plugin/
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) die;
?>

<form name="form-position" action="<?php echo esc_url( admin_url('admin-post.php') ); ?>" method="post" enctype="multipart/form-data" class="c-form <?php if ($_SESSION['position--step'] || isset($step)): ?>c-form--position<?php endif; ?>">
    <div id="action" class="c-form--action c-form--action-position"></div>

<?php
    if ( isset($_SESSION['position--captcha-status']) && $_SESSION['position--captcha-status'] == 'error' ):
?>
    <div class="c-form--validation-static c-form--validation-error">
        <?php _e('Sorry, something went wrong. Please try again', 'biuro-contacts'); ?>
    </div>

<?php

        unset($_SESSION['position--captcha-status']);
    else:
        if (isset($step)) :
?>
            <h2 class="c-form--header"><?php _e('Apply now', 'biuro-contacts'); ?></h2>
<?php
        endif;
    endif;

    if ( !isset($_SESSION['position--step']) && !isset($step) ):
        include_once('biuro-contacts-public--position--step-1.php');
    else:
        include_once('biuro-contacts-public--position--step-2.php');
    endif;
 ?>
    <input type="hidden" name="job_id" value="<?php echo $job_id; ?>">
    <input type="hidden" name="action" value="position_post">
    <?php wp_nonce_field('position_post_nonce'); ?>

<?php
    if ( isset($_SESSION['position--step']) || isset($step) ):
?>
    <input type="hidden" id="g-recaptcha-response" name="captcha" data-action="position/<?php echo $job_id; ?>/">
<?php
    endif;
?>
</form>

<?php
    if(isset($_SESSION['position--s']) && $_SESSION['position--s'] == 1) {
?>
<script>
window.dataLayer = window.dataLayer || [];
window.dataLayer.push({ 'event': 'b2c_form_open_success_validated', 'label': 'Job page' });
</script>

<?php
    unset($_SESSION['position--s']);
}
?>

<?php
    if (isset($_SESSION['position--s']) && $_SESSION['position--s'] == 2) {
?>
<div class="c-modal">
    <div class="c-modal--inner">
        <svg width="67px" height="67px">
            <use xlink:href="#ico--success"></use>
        </svg>
        <p><?php _e('Thank You! Your data was send successfully.', 'biuro-contacts'); ?></p>
        <p><button  class="js-modal--close o-btn c-btn--main"><?php _e('OK', 'biuro-contacts'); ?></button></p>
    </div>
</div>
<script>
window.dataLayer = window.dataLayer || [];
window.dataLayer.push({ 'event': 'b2c_form_submit_success_validated', 'label': 'Job page' });
</script>

<?php
    unset($_SESSION['position--s']);
}
?>
